//
//  SocialSharing.m
//  Shared
//
//  Created by Felipe Arimateia on 7/11/13.
//  Copyright (c) 2013 Felipe Arimateia. All rights reserved.
//

#import "SocialSharing.h"
#import <Social/Social.h>

@implementation SocialSharing

#pragma mark - Twitter

+ (void) postToTwitterWhitMessage:(NSString *)message andURL:(NSArray *)urls andImage:(NSArray *)images andSuccess:(void (^)(BOOL success, BOOL cancell))success{
    
    [SocialSharing postSocialWhitServiceType:SLServiceTypeTwitter andMessage:message andURL:urls andImage:images andSuccess:success];
}

#pragma makr - Facebook

+ (void) postToFacebookWhitMessage:(NSString *)message andURL:(NSArray *)urls andImage:(NSArray *)images andSuccess:(void (^)(BOOL success, BOOL cancell))success{
    
    [SocialSharing postSocialWhitServiceType:SLServiceTypeFacebook andMessage:message andURL:urls andImage:images andSuccess:success];
}

#pragma mark - E-mail

+ (void)postToEmailWhitSubject:(NSString *)subject andMessage:(NSString *)message andImage:(NSArray *)images andDelegate:(id<MFMailComposeViewControllerDelegate>)delegate{
    
    if ([MFMailComposeViewController canSendMail]) {
        
        MFMailComposeViewController *mailer = [[MFMailComposeViewController alloc] init];
        [mailer setMailComposeDelegate:delegate];
        [mailer setSubject:subject];
        [mailer setMessageBody:message isHTML:NO];
        
        if (images != nil && [images count] > 0) {
            for (int i = 0; i < [images count]; i++) {
                
                UIImage *image = [images objectAtIndex:i];
                NSData *data = UIImageJPEGRepresentation(image, 1.0);
                
                [mailer addAttachmentData:data mimeType:@"image/jpg" fileName:[NSString stringWithFormat:@"photo_%d",i+1]];
            }
        }
        
        [[SocialSharing viewController] presentViewController:mailer animated:YES completion:nil];
        
    }
    else {
        //TODO Email not support
    }
}

#pragma mark - Private

+ (void)postSocialWhitServiceType:(NSString *)serviceType andMessage:(NSString *)message andURL:(NSArray *)urls andImage:(NSArray *)images andSuccess:(void (^)(BOOL success, BOOL cancell))success {
    
    if ([SLComposeViewController isAvailableForServiceType:serviceType]) {
        
        SLComposeViewController *controllerSheet = [SLComposeViewController composeViewControllerForServiceType:serviceType];
        
        if (message!= nil) {
            [controllerSheet setInitialText:message];
        }
        
        if (urls != nil && [urls count] > 0) {
            for (NSString *url in urls) {
                [controllerSheet addURL:[NSURL URLWithString:url]];
            }
        }
        
        if (images != nil && [images count] > 0) {
            for (UIImage *image in images) {
                [controllerSheet addImage:image];
            }
        }
        
        SLComposeViewControllerCompletionHandler __block completionHandler = ^(SLComposeViewControllerResult result){
            
            if (result == SLComposeViewControllerResultCancelled && success != nil) {
                success(NO,YES);
            } else if (success != nil){
                success(YES,NO);
            }
            
            [controllerSheet dismissViewControllerAnimated:YES completion:nil];
        };
        
        [controllerSheet setCompletionHandler:completionHandler];
        [[SocialSharing viewController] presentViewController:controllerSheet animated:YES completion:nil];
    }
    else {
        
        NSString *social = nil;
        
        if (serviceType == SLServiceTypeFacebook) {
            social = @"Facebook";
        }
        else {
            if (serviceType == SLServiceTypeTwitter) {
                social = @"Twitter";
            }
        }
        
        NSString *messageAlert = [NSString stringWithFormat:@"Não existe contas de %@ configuradas. Você pode adicionar ou criar uma conta do %@ em Ajustes.",social,social];
        
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:social message:messageAlert delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil];
        [alert show];
        
        if (success != nil) {
            success(NO,YES);
        }
    }
}



+ (UIViewController *)viewController {
    
    return [[[[UIApplication sharedApplication] delegate] window] rootViewController];
}
@end
